#!/usr/bin/env python
import os
from configargparse import ArgParser, YAMLConfigFileParser
from pandas import read_csv
from typing import Any, Dict


class ConfigIssuesToBoard:
    """
    A class for managing configurations from YAML, CSV, and command-line arguments.
    """

    def __init__(self):
        """
        Initialize the configuration manager.
        """
        self.arg_parser = ArgParser(config_file_parser_class=YAMLConfigFileParser)
        self._load_csv_parameters(os.path.join(os.path.dirname(os.path.abspath(__file__)), "arguments_description.csv"))

    def _load_csv_parameters(self, csv_file: str):
        """
        Load parameters from a CSV file.

        Parameters
        ----------
        csv_file : str
            Path to the CSV file.
        """
        parameters = read_csv(csv_file)
        for _, row in parameters.iterrows():
            self.arg_parser.add_argument(
                f"--{row['name']}",
                help=row['description'],
                type=eval(row['type']) if row['type'] != "None" else str,
                default=row['default'] if row['default'] != "None" else None
            )

    def parse(self) -> Dict[str, Any]:
        """
        Parse configuration arguments.

        Returns
        -------
        dict
            Parsed configuration values as a dictionary.
        """
        config = vars(self.arg_parser.parse_args())

        # Ensure filter_labels is a list
        if config.get("filter_labels") and isinstance(config["filter_labels"], str):
            config["filter_labels"] = [label.strip() for label in config["filter_labels"].split(",")]

        # Ensure column_label_map is a dictionary
        if config.get("column_label_map") and isinstance(config["column_label_map"], str):
            config["column_label_map"] = eval(config["column_label_map"])

        return config