from modules import GitLabAPI, DeckAPI, TaskSync
from config import ConfigIssuesToBoard as Config


def run():
    """
    Main function to initialize and execute the synchronization process.
    """
    # Load configuration
    config = Config().parse()

    # Initialize APIs
    gitlab_api = GitLabAPI(config["gitlab_token"])
    deck_api = DeckAPI(
        username=config["nextcloud_username"],
        password=config["nextcloud_password"],
        board_id=config["nextcloud_board_id"],
        column_label_map=config.get("column_label_map", {})
    )

    # Synchronize projects with label filtering
    task_sync = TaskSync(gitlab_api, deck_api, filter_labels=config.get("filter_labels"))
    for project_url in config["gitlab_projects"]:
        task_sync.sync_project_issues(project_url)

if __name__ == "__main__":
    run()